(function() {
    'use strict';

    const app = angular.module('dataiku.charts');

    /**
     * (!) This directive previously was in static/dataiku/js/simple_report/chart_dragdrop.js
     */
    app.directive('chartMultiDragDropZones', function(translate, ChartColumnTypeUtils, WT1) {
        return {
            controller: 'ChartDragDropController',
            link: function($scope, element) {

                $scope.activeDragDrop = {};
                $scope.translate = translate;

                $scope.onDragEnd = function(data) {
                    // Unhide the moved element, as ng-repeat will reuse it
                    if ($scope.activeDragDrop.draggedElementToHide) {
                        $scope.activeDragDrop.draggedElementToHide.show();
                    }
                    clear($scope.activeDragDrop);
                    $scope.setDragInactive();

                    const currentChartIndex = $scope.currentChart && $scope.currentChart.index;
                    if (ChartColumnTypeUtils.isHierarchy(data) && !_.isNil(currentChartIndex)) {
                        const chartType = $scope.charts && $scope.charts[currentChartIndex] && $scope.charts[currentChartIndex].def.type;
                        WT1.event('hierarchy-added-to-chart', { chartType });
                    }
                };

                element[0].addEventListener('dragend', function(e) {
                    $scope.$apply($scope.onDragEnd);
                });
            }
        };
    });
})();
